# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import portailuser.models
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        ("auth", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="ApplicationLog",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                ("name", models.SlugField(unique=True, max_length=32)),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="Ecole",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                ("ident", models.CharField(unique=True, max_length=5)),
                ("nom_propre", models.CharField(unique=True, max_length=15)),
                ("nom_commun", models.CharField(unique=True, max_length=15)),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="JetonConnexion",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                (
                    "date_limite",
                    models.DateTimeField(
                        default=portailuser.models.date_limite_default
                    ),
                ),
                (
                    "valeur",
                    models.CharField(
                        default=portailuser.models.valeur_default, max_length=40
                    ),
                ),
                (
                    "ecole_depart",
                    models.ForeignKey(to="portailuser.Ecole", on_delete=models.CASCADE),
                ),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="LogEntry",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                ("date", models.DateTimeField(auto_now_add=True)),
                ("operation", models.TextField()),
                (
                    "application",
                    models.ForeignKey(
                        to="portailuser.ApplicationLog", on_delete=models.CASCADE
                    ),
                ),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="Permission",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                ("ident", models.CharField(max_length=64)),
                ("nom", models.CharField(max_length=25)),
                ("desc", models.CharField(max_length=128)),
                (
                    "ecole",
                    models.ForeignKey(
                        to="portailuser.Ecole", null=True, on_delete=models.CASCADE
                    ),
                ),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="PortailUser",
            fields=[
                (
                    "user_ptr",
                    models.OneToOneField(
                        parent_link=True,
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        to=settings.AUTH_USER_MODEL,
                        on_delete=models.CASCADE,
                    ),
                ),
                ("jabber_mdp_temp", models.CharField(max_length=32, blank=True)),
                ("edt_club_events", models.SmallIntegerField(null=True)),
                (
                    "ecole",
                    models.ForeignKey(to="portailuser.Ecole", on_delete=models.CASCADE),
                ),
                ("permissions", models.ManyToManyField(to="portailuser.Permission")),
            ],
            options={
                "abstract": False,
                "verbose_name": "user",
                "verbose_name_plural": "users",
            },
            bases=("auth.user",),
        ),
        migrations.AlterUniqueTogether(
            name="permission", unique_together={("ident", "ecole")},
        ),
        migrations.AddField(
            model_name="logentry",
            name="user",
            field=models.ForeignKey(
                related_name="logs",
                to="portailuser.PortailUser",
                on_delete=models.CASCADE,
            ),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name="jetonconnexion",
            name="utilisateur",
            field=models.ForeignKey(
                to="portailuser.PortailUser", on_delete=models.CASCADE
            ),
            preserve_default=True,
        ),
    ]
